==> haskell-insert-ordered-containers-0.2.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.2
id: insert-ordered-containers-0.2.2-9UNPWZu5rEG9gjo8h2Xt95
key: insert-ordered-containers-0.2.2-9UNPWZu5rEG9gjo8h2Xt95
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retaining insertion order for traversals.
description:
    Associative containers retaining insertion order for traversals.
    .
    The implementation is based on `unordered-containers`.
category: Web
abi: 87c6def358601f30fcec1ca04bf0b683
exposed: True
exposed-modules:
    Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules: Data.HashMap.InsOrd.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/insert-ordered-containers-0.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/insert-ordered-containers-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/insert-ordered-containers-0.2.2
hs-libraries: HSinsert-ordered-containers-0.2.2-9UNPWZu5rEG9gjo8h2Xt95
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17.1-ENKPXwJVBySCOhb6zFHax3
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.2-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.2
id: insert-ordered-containers-0.2.2-A9ItFeaHZCIFpAqu8gtwcA
key: insert-ordered-containers-0.2.2-A9ItFeaHZCIFpAqu8gtwcA
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retaining insertion order for traversals.
description:
    Associative containers retaining insertion order for traversals.
    .
    The implementation is based on `unordered-containers`.
category: Web
abi: e2657189321194caf693d81dd2892e18
exposed: True
exposed-modules:
    Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules: Data.HashMap.InsOrd.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/insert-ordered-containers-0.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/insert-ordered-containers-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/insert-ordered-containers-0.2.2
hs-libraries: HSinsert-ordered-containers-0.2.2-A9ItFeaHZCIFpAqu8gtwcA
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17.1-LAhRbmSla4gFq61XVUqFfx
    semigroupoids-5.3.3-5c90p3ZZL5SEVl9HRh2nSh text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
